@@ -32,6 +32,7 @@ sub draw {
     my $yper = $range->per();
 
     my @vals = @{ $series->values() };
+    my @keys = @{ $series->keys() };
 
     my $color = $clicker->color_allocator->next();
 
@@ -46,7 +47,7 @@ sub draw {
     for(0..($series->key_count() - 1)) {
         # Add the series_count times the width to so that each bar
         # gets rendered with it's partner in the other series.
-        my $x = ($xper * $_) + ($self->{'SCOUNT'} * $bwidth);
+        my $x = ($xper * $keys[$_]) + ($self->{'SCOUNT'} * $bwidth);
         my $y = $height - ($yper * ($vals[$_] - $min));
         $cr->rectangle(
             $x + $padding / 2, $y,
